==> qianxing-openapi-0.1.3.tar.gz: qianxing-openapi-0.1.3/setup.py <==
from distutils.core import setup
from setuptools import find_packages

# Read the README file
with open("README.md", "r", encoding="utf-8") as f:
    long_description = f.read()

# Read requirements from requirements.txt
def parse_requirements(filename):
    with open(filename, "r") as file:
        return [line.strip() for line in file if line.strip() and not line.startswith("#")]

setup(
    name="qianxing-openapi",
    version="0.1.3",
    description="Qianxing OpenAPI SDK for Python - A client library for accessing Qianxing's simulation platform",
    long_description=long_description,
    long_description_content_type="text/markdown",
    author="Zhihong Luo",
    author_email="luozhihong@risenlighten.com",
    url="https://github.com/risenlighten-qianxing/openapi-sdk-python",
    packages=find_packages(),
    install_requires=[
        "requests>=2.25.0",
    ],
    python_requires=">=3.0",
    keywords=["Qianxing", "Lasvsim", "自动驾驶", "OpenAPI", "Simulation", "Autonomous Driving"],
    include_package_data=True,
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Topic :: Software Development :: Libraries :: Python Modules",
    ],
    project_urls={
        "Source": "https://github.com/risenlighten-qianxing/openapi-sdk-python",
        "Bug Reports": "https://github.com/risenlighten-qianxing/openapi-sdk-python/issues",
    },
)

==> qianxing-openapi-0.1.4.tar.gz: qianxing-openapi-0.1.4/setup.py <==
from distutils.core import setup
from setuptools import find_packages

# Read the README file
with open("README.md", "r", encoding="utf-8") as f:
    long_description = f.read()

# Read requirements from requirements.txt


def parse_requirements(filename):
    with open(filename, "r") as file:
        return [line.strip() for line in file if line.strip() and not line.startswith("#")]


setup(
    name="qianxing-openapi",
    version="0.1.4",
    description="Qianxing OpenAPI SDK for Python - A client library for accessing Qianxing's simulation platform",
    long_description=long_description,
    long_description_content_type="text/markdown",
    author="Zhihong Luo",
    author_email="luozhihong@risenlighten.com",
    url="https://github.com/risenlighten-qianxing/openapi-sdk-python",
    packages=find_packages(),
    install_requires=[
        "requests>=2.25.0",
    ],
    python_requires=">=3.0",
    keywords=["Qianxing", "Lasvsim", "自动驾驶",
              "OpenAPI", "Simulation", "Autonomous Driving"],
    include_package_data=True,
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Topic :: Software Development :: Libraries :: Python Modules",
    ],
    project_urls={
        "Source": "https://github.com/risenlighten-qianxing/openapi-sdk-python",
        "Bug Reports": "https://github.com/risenlighten-qianxing/openapi-sdk-python/issues",
    },
)
